Coverage for /home/andrew/Documents/Research/gwent/gwent/__init__.py: 100%

# Coverage for /home/andrew/Documents/Research/gwent/gwent/__init__.py : 100%

## 4 statements 4 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# -*- coding: utf-8 -*-

2

3"""Top-level package for gwent."""

4

5 __author__ = """Andrew Kaiser"""

6 __email__ = "andrewkaiser70@gmail.com"

7 __version__ = "0.3.0"